/* $Cambridge: hermes/src/prayer/lib/mymutex.c,v 1.4 2009/10/16 14:56:29 dpc22 Exp $ */

/************************************************
 *    Prayer - a Webmail Interface              *
 ************************************************/

/* Copyright (c) University of Cambridge 2000 - 2008 */
/* See the file NOTICE for conditions of use and distribution. */

#include "lib.h"

#if defined(MUTEX_SEMAPHORE) && !defined(__stub_semtimedop)
#  include "mymutex_sem.c"
#else
#  include "mymutex_file.c"
#endif
